@@ -8,6 +8,10 @@ class WhiteboxPluginFlightManagementConfig(AppConfig):
     verbose_name = "Whitebox Plugin Flight Management"
 
     def ready(self):
-        from .models import FlightSession
+        from .models import FlightSession, FlightSessionRecording
 
         model_registry.register("flight.FlightSession", FlightSession)
+        model_registry.register(
+            "flight.FlightSessionRecording",
+            FlightSessionRecording,
+        )
